clear();

function f = rechteSeite(t,y)
    MINBETA = 0.00001;  //Grenze zum Umschalten des Modells für Geradeausfahrt
    
    //Tests:
    //MINBETA = 0.0001;  //O.K.
    //MINBETA = 0.001;  //O.K.
    //MINBETA = 0.01;  //NICHT O.K.


    q = 0.1;
    r = 0.1;
    m = 1.0;
    quad_lang = 0.2;
    quad_breit = 0.1;
    J = m*(quad_breit*quad_breit + quad_lang*quad_lang)/12;

    //bbeta  = 0.1*%pi;
    //Dbbeta = 0.0;

    //Testweise Zeitabhängig
    bbeta  =  0.2*cos(t);
    Dbbeta = -0.2*sin(t);

    FA   = 10;

    xs   = y(1,1);
    ys   = y(2,1);
    phi  = y(3,1);

    vx  = y(4,1);
    vy  = y(5,1);
    om  = y(6,1);

    SP = sin(phi);
    CP = cos(phi);
    SB = sin(bbeta);
    CB = cos(bbeta);
    SPB = sin(phi+bbeta);
    CPB = cos(phi+bbeta);

    //Zwangskräfte berechnen
    if abs(bbeta)>MINBETA then
        //Momentanpol:
        b = (r+q)/(SPB*CP-CPB*SP);
        xP = xs + r*CP - b*SPB;
        yP = ys + r*SP + b*CPB;
        QQ = (om+Dbbeta)*CPB*CP-om*SPB*SP;
        RR = (om+Dbbeta)*SPB*SP - om*CPB*CP;
        Db = -(r+q)* ( (SPB*CP-CPB*SP)^(-2) ) * (QQ+RR);//Zeitliche Ableitung: vorangestelltes D!
        DxP = vx - r*om*SP-Db*SPB-b*(om+Dbbeta)*CPB;
        DyP = vy + r*om*CP+Db*CPB-b*(om+Dbbeta)*SPB;


        //Herleitung:
        //  DDx = (FHx + FVx + FAx)/m;
        //  DDy = (FHy + FVy + FAy)/m;
        //  -DDphi*(y-yP)*m-om*(vy-DyP)*m = -FH*SP - FV*SPB + FA*CPB;
        //   DDphi*(x-xP)*m+om*(vx-DxP)*m =  FH*CP + FV*CPB + FA*SPB;

        //   DDphi = (-q*FH+r*FV*(CP*CPB+SP*SPB)+r*FA*(CP*SPB-SP*CPB))/J
        EEE = q/J;
        FFF = r*(CP*CPB+SP*SPB)/J;
        GGG = r*(CP*SPB-SP*CPB)/J;
        //   DDphi = -EEE*FH + FFF*FV + GGG*FA
        HHH =  om*(vy-DyP)*m;
        III =  om*(vx-DxP)*m;
        JJJ =  (ys - yP)*m;
        KKK =  (xs - xP)*m;
        //  -DDphi*JJJ-HHH = -FH*SP - FV*SPB + FA*CPB;
        //   DDphi*KKK+III =  FH*CP + FV*CPB + FA*SPB;
        //
        //  -(-EEE*FH + FFF*FV + GGG*FA)*JJJ-HHH = -FH*SP - FV*SPB + FA*CPB;
        //   (-EEE*FH + FFF*FV + GGG*FA)*KKK+III =  FH*CP + FV*CPB + FA*SPB;
        //
        //     EEE*JJJ*FH - FFF*JJJ*FV - GGG*JJJ*FA - HHH = -FH*SP - FV*SPB + FA*CPB;
        //    -EEE*KKK*FH + FFF*KKK*FV + GGG*KKK*FA + III =  FH*CP + FV*CPB + FA*SPB;
        //     EEE*JJJ*FH + FH*SP - FFF*JJJ*FV + FV*SPB   =   + FA*CPB + GGG*JJJ*FA + HHH;
        //    -EEE*KKK*FH - FH*CP + FFF*KKK*FV - FV*CPB   =   + FA*SPB - GGG*KKK*FA - III;

        // AA * [FH;FV] = bb

        AA = [ EEE*JJJ + SP , - FFF*JJJ + SPB;
              -EEE*KKK - CP ,   FFF*KKK - CPB ];

        bb = [FA*CPB + GGG*JJJ*FA + HHH ; FA*SPB - GGG*KKK*FA - III ];

        FHFV = inv(AA)*bb;

        FH   = FHFV(1);
        FV   = FHFV(2);

        FHx = -FH*SP;
        FHy =  FH*CP;
        FVx = -FV*SPB;
        FVy =  FV*CPB;
    else
        //Wenn Geradeausfahrt
        FH   = 0;
        FV   = 0;

        FHx = 0;
        FHy = 0;
        FVx = 0;
        FVy = 0;
    end
    //Ende Zwangskräfte berechnen

    FAx = FA*CPB;
    FAy = FA*SPB;

    f(1,1) = vx;
    f(2,1) = vy;
    f(3,1) = om;

    f(4,1) = (FHx + FVx + FAx)/m;
    f(5,1) = (FHy + FVy + FAy)/m;
    f(6,1) = (-q*FH+r*FV*(CP*CPB+SP*SPB)+r*FA*(CP*SPB-SP*CPB))/J;
endfunction

t = linspace(0,3,3000);
y0 = [0,0,0,0,0,0]';
t0 = 0;
y  = ode(y0,t0,t,rechteSeite);

plot(y(1,:)',y(2,:)');